@@ -1,6 +1,6 @@
 package Pod::Weaver;
 # ABSTRACT: weave together a Pod document from an outline
-$Pod::Weaver::VERSION = '4.014';
+$Pod::Weaver::VERSION = '4.017';
 use Moose;
 use namespace::autoclean;
 
@@ -165,7 +165,7 @@ sub new_with_default_config {
 
 sub new_from_config {
   my ($class, $arg, $new_arg) = @_;
-  
+
   my $root = $arg->{root} || '.';
   my $name = File::Spec->catfile($root, 'weaver');
   my ($sequence) = Pod::Weaver::Config::Finder->new->read_config($name);
@@ -232,7 +232,7 @@ Pod::Weaver - weave together a Pod document from an outline
 
 =head1 VERSION
 
-version 4.014
+version 4.017
 
 =head1 SYNOPSIS
 
@@ -310,7 +310,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alex Peters Apocalypse Blabos de Blebe Caleb Cushing Christian Walde Christopher J. Madsen Chris Weyl Dave Rolsky David E. Wheeler Golden Zurborg Florian Ragwitz Jonathan "Duke" Leto Joshua Keroes Karen Etheridge Kent Fredric Marcel Gruenauer Randy Stauner Sam Graham Shlomi Fish
+=for stopwords Alex Peters Apocalypse Blabos de Blebe Caleb Cushing Christian Walde Christopher J. Madsen Chris Weyl Dave Houston Rolsky David E. Wheeler Golden Miguel Susano Pinto Zurborg Doug Bell Florian Ragwitz Jonathan "Duke" Leto Joshua Keroes Karen Etheridge Kent Fredric Kivanc Yazan Marcel Gruenauer Randy Stauner Ricardo Signes Sam Graham Shlomi Fish
 
 =over 4
 
@@ -344,6 +344,10 @@ Chris Weyl <cweyl@alumni.drew.edu>
 
 =item *
 
+Dave Houston <dave.houston@gmail.com>
+
+=item *
+
 Dave Rolsky <autarch@urth.org>
 
 =item *
@@ -356,10 +360,18 @@ David Golden <dagolden@cpan.org>
 
 =item *
 
+David Miguel Susano Pinto <carandraug+dev@gmail.com>
+
+=item *
+
 David Zurborg <post@david-zurb.org>
 
 =item *
 
+Doug Bell <doug@preaction.me>
+
+=item *
+
 Florian Ragwitz <rafl@debian.org>
 
 =item *
@@ -380,6 +392,10 @@ Kent Fredric <kentfredric@gmail.com>
 
 =item *
 
+Kivanc Yazan <kyzn@cpan.org>
+
+=item *
+
 Marcel Gruenauer <hanekomu@gmail.com>
 
 =item *
@@ -388,6 +404,10 @@ Randy Stauner <randy@magnificent-tears.com>
 
 =item *
 
+Ricardo Signes <rjbs@semiotic.systems>
+
+=item *
+
 Sam Graham <git@illusori.co.uk>
 
 =item *
@@ -398,7 +418,7 @@ Shlomi Fish <shlomif@shlomifish.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
